@@ -58,7 +58,7 @@ def get_fileobj(byte_io):
         byte_io = zf.open(filename, mode='r')
     else:
         byte_io.seek(0)  # rewind what zipfile.is_zipfile did
-    return io.TextIOWrapper(byte_io, encoding='utf-8')
+    return byte_io
 
 
 def is_whitelisted_host(host):
@@ -147,7 +147,7 @@ class HostBlocker:
             with open(filename, 'r', encoding='utf-8') as f:
                 for line in f:
                     target.add(line.strip())
-        except OSError:
+        except (OSError, UnicodeDecodeError):
             log.misc.exception("Failed to read host blocklist!")
 
         return True
@@ -205,6 +205,54 @@ class HostBlocker:
                 download.finished.connect(
                     functools.partial(self.on_download_finished, download))
 
+    def _parse_line(self, line):
+        """Parse a line from a host file.
+
+        Args:
+            line: The bytes object to parse.
+
+        Returns:
+            True if parsing succeeded, False otherwise.
+        """
+        if line.startswith(b'#'):
+            # Ignoring comments early so we don't have to care about
+            # encoding errors in them.
+            return True
+
+        try:
+            line = line.decode('utf-8')
+        except UnicodeDecodeError:
+            log.misc.error("Failed to decode: {!r}".format(line))
+            return False
+
+        # Remove comments
+        try:
+            hash_idx = line.index('#')
+            line = line[:hash_idx]
+        except ValueError:
+            pass
+
+        line = line.strip()
+        # Skip empty lines
+        if not line:
+            return True
+
+        parts = line.split()
+        if len(parts) == 1:
+            # "one host per line" format
+            host = parts[0]
+        elif len(parts) == 2:
+            # /etc/hosts format
+            host = parts[1]
+        else:
+            log.misc.error("Failed to parse: {!r}".format(line))
+            return False
+
+        if host not in self.WHITELISTED:
+            self._blocked_hosts.add(host)
+
+        return True
+
     def _merge_file(self, byte_io):
         """Read and merge host files.
 
@@ -218,35 +266,18 @@ class HostBlocker:
         line_count = 0
         try:
             f = get_fileobj(byte_io)
-        except (OSError, UnicodeDecodeError, zipfile.BadZipFile,
-                zipfile.LargeZipFile, LookupError) as e:
+        except (OSError, zipfile.BadZipFile, zipfile.LargeZipFile,
+                LookupError) as e:
             message.error("adblock: Error while reading {}: {} - {}".format(
                 byte_io.name, e.__class__.__name__, e))
             return
+
         for line in f:
             line_count += 1
-            # Remove comments
-            try:
-                hash_idx = line.index('#')
-                line = line[:hash_idx]
-            except ValueError:
-                pass
-            line = line.strip()
-            # Skip empty lines
-            if not line:
-                continue
-            parts = line.split()
-            if len(parts) == 1:
-                # "one host per line" format
-                host = parts[0]
-            elif len(parts) == 2:
-                # /etc/hosts format
-                host = parts[1]
-            else:
+            ok = self._parse_line(line)
+            if not ok:
                 error_count += 1
-                continue
-            if host not in self.WHITELISTED:
-                self._blocked_hosts.add(host)
+
         log.misc.debug("{}: read {} lines".format(byte_io.name, line_count))
         if error_count > 0:
             message.error("adblock: {} read errors for {}".format(
