@@ -27,7 +27,7 @@ import collections
 from PyQt5.QtCore import pyqtSlot, pyqtSignal, QTimer
 from PyQt5.QtNetwork import QNetworkRequest, QNetworkReply
 
-from qutebrowser.utils import message, usertypes, log, urlutils
+from qutebrowser.utils import message, usertypes, log, urlutils, utils
 from qutebrowser.browser import downloads
 from qutebrowser.browser.webkit import http
 from qutebrowser.browser.webkit.network import networkmanager
@@ -366,11 +366,12 @@ class DownloadManager(downloads.AbstractDownloadManager):
             win_id, None, self)
 
     @pyqtSlot('QUrl')
-    def get(self, url, **kwargs):
+    def get(self, url, *, user_agent=None, **kwargs):
         """Start a download with a link URL.
 
         Args:
             url: The URL to get, as QUrl
+            user_agent: The UA to set for the request, or None.
             **kwargs: passed to get_request().
 
         Return:
@@ -380,8 +381,32 @@ class DownloadManager(downloads.AbstractDownloadManager):
             urlutils.invalid_url_error(url, "start download")
             return
         req = QNetworkRequest(url)
+        if user_agent is not None:
+            req.setHeader(QNetworkRequest.UserAgentHeader, user_agent)
         return self.get_request(req, **kwargs)
 
+    def get_mhtml(self, tab, target):
+        """Download the given tab as mhtml to the given DownloadTarget."""
+        assert tab.backend == usertypes.Backend.QtWebKit
+        from qutebrowser.browser.webkit import mhtml
+
+        if target is not None:
+            mhtml.start_download_checked(target, tab=tab)
+            return
+
+        suggested_fn = utils.sanitize_filename(tab.title() + ".mhtml")
+
+        filename = downloads.immediate_download_path()
+        if filename is not None:
+            target = downloads.FileDownloadTarget(filename)
+            mhtml.start_download_checked(target, tab=tab)
+        else:
+            question = downloads.get_filename_question(
+                suggested_filename=suggested_fn, url=tab.url(), parent=tab)
+            question.answered.connect(functools.partial(
+                mhtml.start_download_checked, tab=tab))
+            message.global_bridge.ask(question, blocking=False)
+
     def get_request(self, request, *, target=None, **kwargs):
         """Start a download with a QNetworkRequest.
 
