@@ -24,11 +24,17 @@ Module attributes:
     _HANDLERS: The handlers registered via decorators.
 """
 
+import sys
+import time
+import datetime
 import urllib.parse
 
+from PyQt5.QtCore import QUrlQuery
+
 import qutebrowser
 from qutebrowser.utils import (version, utils, jinja, log, message, docutils,
-                               objreg, usertypes)
+                               objreg)
+from qutebrowser.misc import objects
 
 
 pyeval_output = ":pyeval was never called"
@@ -89,8 +95,7 @@ class add_handler:  # pylint: disable=invalid-name
         return function
 
     def wrapper(self, *args, **kwargs):
-        used_backend = usertypes.arg2backend[objreg.get('args').backend]
-        if self._backend is not None and used_backend != self._backend:
+        if self._backend is not None and objects.backend != self._backend:
             return self.wrong_backend_handler(*args, **kwargs)
         else:
             return self._function(*args, **kwargs)
@@ -158,6 +163,87 @@ def qute_bookmarks(_url):
     return 'text/html', html
 
 
+@add_handler('history')  # noqa
+def qute_history(url):
+    """Handler for qute:history. Display history."""
+    # Get current date from query parameter, if not given choose today.
+    curr_date = datetime.date.today()
+    try:
+        query_date = QUrlQuery(url).queryItemValue("date")
+        if query_date:
+            curr_date = datetime.datetime.strptime(query_date, "%Y-%m-%d")
+            curr_date = curr_date.date()
+    except ValueError:
+        log.misc.debug("Invalid date passed to qute:history: " + query_date)
+
+    one_day = datetime.timedelta(days=1)
+    next_date = curr_date + one_day
+    prev_date = curr_date - one_day
+
+    def history_iter(reverse):
+        """Iterate through the history and get items we're interested in."""
+        curr_timestamp = time.mktime(curr_date.timetuple())
+        history = objreg.get('web-history').history_dict.values()
+        if reverse:
+            history = reversed(history)
+
+        for item in history:
+            # If we can't apply the reverse performance trick below,
+            # at least continue as early as possible with old items.
+            # This gets us down from 550ms to 123ms with 500k old items on my
+            # machine.
+            if item.atime < curr_timestamp and not reverse:
+                continue
+
+            # Convert timestamp
+            try:
+                item_atime = datetime.datetime.fromtimestamp(item.atime)
+            except (ValueError, OSError, OverflowError):
+                log.misc.debug("Invalid timestamp {}.".format(item.atime))
+                continue
+
+            if reverse and item_atime.date() < curr_date:
+                # If we could reverse the history in-place, and this entry is
+                # older than today, only older entries will follow, so we can
+                # abort here.
+                return
+
+            # Skip items not on curr_date
+            # Skip redirects
+            # Skip qute:// links
+            is_internal = item.url.scheme() == 'qute'
+            is_not_today = item_atime.date() != curr_date
+            if item.redirect or is_internal or is_not_today:
+                continue
+
+            # Use item's url as title if there's no title.
+            item_url = item.url.toDisplayString()
+            item_title = item.title if item.title else item_url
+            display_atime = item_atime.strftime("%X")
+
+            yield (item_url, item_title, display_atime)
+
+    if sys.hexversion >= 0x03050000:
+        # On Python >= 3.5 we can reverse the ordereddict in-place and thus
+        # apply an additional performance improvement in history_iter.
+        # On my machine, this gets us down from 550ms to 72us with 500k old
+        # items.
+        history = list(history_iter(reverse=True))
+    else:
+        # On Python 3.4, we can't do that, so we'd need to copy the entire
+        # history to a list. There, filter first and then reverse it here.
+        history = reversed(list(history_iter(reverse=False)))
+
+    html = jinja.render('history.html',
+                        title='History',
+                        history=history,
+                        curr_date=curr_date,
+                        next_date=next_date,
+                        prev_date=prev_date,
+                        today=datetime.date.today())
+    return 'text/html', html
+
+
 @add_handler('pyeval')
 def qute_pyeval(_url):
     """Handler for qute:pyeval."""
