@@ -211,7 +211,8 @@ class NetworkManager(QNetworkAccessManager):
             request.deleteLater()
         self.shutting_down.emit()
 
-    @pyqtSlot('QNetworkReply*', 'QList<QSslError>')
+    # No @pyqtSlot here, see
+    # https://github.com/qutebrowser/qutebrowser/issues/2213
     def on_ssl_errors(self, reply, errors):  # pragma: no mccabe
         """Decide if SSL errors should be ignored or not.
 
@@ -434,7 +435,7 @@ class NetworkManager(QNetworkAccessManager):
                                  tab=self._tab_id)
                 current_url = tab.url()
             except (KeyError, RuntimeError, TypeError):
-                # https://github.com/The-Compiler/qutebrowser/issues/889
+                # https://github.com/qutebrowser/qutebrowser/issues/889
                 # Catching RuntimeError and TypeError because we could be in
                 # the middle of the webpage shutdown here.
                 current_url = QUrl()
