@@ -27,8 +27,7 @@ Module attributes:
 
 import functools
 
-from qutebrowser.completion.models import (miscmodels, urlmodel, configmodel,
-                                           base)
+from qutebrowser.completion.models import miscmodels, urlmodel, configmodel
 from qutebrowser.utils import objreg, usertypes, log, debug
 from qutebrowser.config import configdata, config
 
@@ -115,11 +114,11 @@ def init_session_completion():
     _instances[usertypes.Completion.sessions] = model
 
 
-def _init_empty_completion():
-    """Initialize empty completion model."""
-    log.completion.debug("Initializing empty completion.")
-    if usertypes.Completion.empty not in _instances:
-        _instances[usertypes.Completion.empty] = base.BaseCompletionModel()
+def _init_bind_completion():
+    """Initialize the command completion model."""
+    log.completion.debug("Initializing bind completion.")
+    model = miscmodels.BindCompletionModel()
+    _instances[usertypes.Completion.bind] = model
 
 
 INITIALIZERS = {
@@ -133,7 +132,7 @@ INITIALIZERS = {
     usertypes.Completion.quickmark_by_name: init_quickmark_completions,
     usertypes.Completion.bookmark_by_url: init_bookmark_completions,
     usertypes.Completion.sessions: init_session_completion,
-    usertypes.Completion.empty: _init_empty_completion,
+    usertypes.Completion.bind: _init_bind_completion,
 }
 
 
@@ -191,5 +190,7 @@ def init():
     keyconf = objreg.get('key-config')
     keyconf.changed.connect(
         functools.partial(update, [usertypes.Completion.command]))
+    keyconf.changed.connect(
+        functools.partial(update, [usertypes.Completion.bind]))
 
     objreg.get('config').changed.connect(_update_aliases)
