@@ -32,7 +32,7 @@ class CommandCompletionModel(base.BaseCompletionModel):
 
     """A CompletionModel filled with non-hidden commands and descriptions."""
 
-    # https://github.com/The-Compiler/qutebrowser/issues/545
+    # https://github.com/qutebrowser/qutebrowser/issues/545
     # pylint: disable=abstract-method
 
     COLUMN_WIDTHS = (20, 60, 20)
@@ -50,9 +50,11 @@ class HelpCompletionModel(base.BaseCompletionModel):
 
     """A CompletionModel filled with help topics."""
 
-    # https://github.com/The-Compiler/qutebrowser/issues/545
+    # https://github.com/qutebrowser/qutebrowser/issues/545
     # pylint: disable=abstract-method
 
+    COLUMN_WIDTHS = (20, 60, 20)
+
     def __init__(self, parent=None):
         super().__init__(parent)
         self._init_commands()
@@ -87,7 +89,7 @@ class QuickmarkCompletionModel(base.BaseCompletionModel):
 
     """A CompletionModel filled with all quickmarks."""
 
-    # https://github.com/The-Compiler/qutebrowser/issues/545
+    # https://github.com/qutebrowser/qutebrowser/issues/545
     # pylint: disable=abstract-method
 
     def __init__(self, parent=None):
@@ -102,7 +104,7 @@ class BookmarkCompletionModel(base.BaseCompletionModel):
 
     """A CompletionModel filled with all bookmarks."""
 
-    # https://github.com/The-Compiler/qutebrowser/issues/545
+    # https://github.com/qutebrowser/qutebrowser/issues/545
     # pylint: disable=abstract-method
 
     def __init__(self, parent=None):
@@ -117,7 +119,7 @@ class SessionCompletionModel(base.BaseCompletionModel):
 
     """A CompletionModel filled with session names."""
 
-    # https://github.com/The-Compiler/qutebrowser/issues/545
+    # https://github.com/qutebrowser/qutebrowser/issues/545
     # pylint: disable=abstract-method
 
     def __init__(self, parent=None):
@@ -249,7 +251,7 @@ class BindCompletionModel(base.BaseCompletionModel):
 
     """A CompletionModel filled with all bindable commands and descriptions."""
 
-    # https://github.com/The-Compiler/qutebrowser/issues/545
+    # https://github.com/qutebrowser/qutebrowser/issues/545
     # pylint: disable=abstract-method
 
     COLUMN_WIDTHS = (20, 60, 20)
