@@ -70,10 +70,11 @@ class BaseKeyParser(QObject):
         request_leave: Emitted to request leaving a mode.
                        arg 0: Mode to leave.
                        arg 1: Reason for leaving.
+                       arg 2: Ignore the request if we're not in that mode
     """
 
     keystring_updated = pyqtSignal(str)
-    request_leave = pyqtSignal(usertypes.KeyMode, str)
+    request_leave = pyqtSignal(usertypes.KeyMode, str, bool)
     do_log = True
     passthrough = False
 
@@ -129,9 +130,11 @@ class BaseKeyParser(QObject):
         try:
             cmdstr = self.special_bindings[binding]
         except KeyError:
-            self._debug_log("No binding found for {}.".format(binding))
+            self._debug_log("No special binding found for {}.".format(binding))
             return False
-        self.execute(cmdstr, self.Type.special)
+        count, _command = self._split_count()
+        self.execute(cmdstr, self.Type.special, count)
+        self.clear_keystring()
         return True
 
     def _split_count(self):
@@ -193,7 +196,7 @@ class BaseKeyParser(QObject):
         if match == self.Match.definitive:
             self._debug_log("Definitive match for '{}'.".format(
                 self._keystring))
-            self._keystring = ''
+            self.clear_keystring()
             self.execute(binding, self.Type.chain, count)
         elif match == self.Match.ambiguous:
             self._debug_log("Ambiguous match for '{}'.".format(
@@ -205,7 +208,7 @@ class BaseKeyParser(QObject):
         elif match == self.Match.none:
             self._debug_log("Giving up with '{}', no matches".format(
                 self._keystring))
-            self._keystring = ''
+            self.clear_keystring()
         else:
             raise AssertionError("Invalid match value {!r}".format(match))
         return match
@@ -271,7 +274,7 @@ class BaseKeyParser(QObject):
         time = config.get('input', 'timeout')
         if time == 0:
             # execute immediately
-            self._keystring = ''
+            self.clear_keystring()
             self.execute(binding, self.Type.chain, count)
         else:
             # execute in `time' ms
@@ -289,8 +292,7 @@ class BaseKeyParser(QObject):
             command/count: As if passed to self.execute()
         """
         self._debug_log("Executing delayed command now!")
-        self._keystring = ''
-        self.keystring_updated.emit(self._keystring)
+        self.clear_keystring()
         self.execute(command, self.Type.chain, count)
 
     def handle(self, e):
@@ -307,7 +309,9 @@ class BaseKeyParser(QObject):
         if handled or not self._supports_chains:
             return handled
         match = self._handle_single_key(e)
-        self.keystring_updated.emit(self._keystring)
+        # don't emit twice if the keystring was cleared in self.clear_keystring
+        if self._keystring:
+            self.keystring_updated.emit(self._keystring)
         return match != self.Match.none
 
     def read_config(self, modename=None):
@@ -366,6 +370,8 @@ class BaseKeyParser(QObject):
 
     def clear_keystring(self):
         """Clear the currently entered key sequence."""
-        self._debug_log("discarding keystring '{}'.".format(self._keystring))
-        self._keystring = ''
-        self.keystring_updated.emit(self._keystring)
+        if self._keystring:
+            self._debug_log("discarding keystring '{}'.".format(
+                self._keystring))
+            self._keystring = ''
+            self.keystring_updated.emit(self._keystring)
