@@ -262,19 +262,20 @@ def get_backend(args):
 
 def check_qt_version(backend):
     """Check if the Qt version is recent enough."""
-    from PyQt5.QtCore import qVersion, PYQT_VERSION, PYQT_VERSION_STR
-    from qutebrowser.utils import qtutils
-    if (qtutils.version_check('5.2.0', operator.lt) or
+    from PyQt5.QtCore import PYQT_VERSION, PYQT_VERSION_STR
+    from qutebrowser.utils import qtutils, version
+    if (qtutils.version_check('5.2.0', operator.lt, strict=True) or
             PYQT_VERSION < 0x050200):
         text = ("Fatal error: Qt and PyQt >= 5.2.0 are required, but Qt {} / "
-                "PyQt {} is installed.".format(qVersion(), PYQT_VERSION_STR))
+                "PyQt {} is installed.".format(version.qt_version(),
+                                               PYQT_VERSION_STR))
         _die(text)
     elif (backend == 'webengine' and (
-            qtutils.version_check('5.7.1', operator.lt) or
+            qtutils.version_check('5.7.1', operator.lt, strict=True) or
             PYQT_VERSION < 0x050700)):
         text = ("Fatal error: Qt >= 5.7.1 and PyQt >= 5.7 are required for "
                 "QtWebEngine support, but Qt {} / PyQt {} is installed."
-                .format(qVersion(), PYQT_VERSION_STR))
+                .format(version.qt_version(), PYQT_VERSION_STR))
         _die(text)
 
 
