@@ -148,13 +148,8 @@ class ReadlineBridge:
         self._deleted[widget] = widget.selectedText()
         widget.del_()
 
-    @cmdutils.register(instance='readline-bridge', hide=True,
-                       modes=[typ.KeyMode.command, typ.KeyMode.prompt])
-    def rl_unix_word_rubout(self):
-        """Remove chars from the cursor to the beginning of the word.
-
-        This acts like readline's unix-word-rubout.
-        """
+    def _rubout(self, delim):
+        """Delete backwards using the characters in delim as boundaries."""
         widget = self._widget()
         if widget is None:
             return
@@ -163,14 +158,14 @@ class ReadlineBridge:
 
         target_position = cursor_position
 
-        is_word_boundary = True
-        while is_word_boundary and target_position > 0:
-            is_word_boundary = text[target_position - 1] == " "
+        is_boundary = True
+        while is_boundary and target_position > 0:
+            is_boundary = text[target_position - 1] in delim
             target_position -= 1
 
-        is_word_boundary = False
-        while not is_word_boundary and target_position > 0:
-            is_word_boundary = text[target_position - 1] == " "
+        is_boundary = False
+        while not is_boundary and target_position > 0:
+            is_boundary = text[target_position - 1] in delim
             target_position -= 1
 
         moveby = cursor_position - target_position - 1
@@ -178,6 +173,40 @@ class ReadlineBridge:
         self._deleted[widget] = widget.selectedText()
         widget.del_()
 
+    @cmdutils.register(instance='readline-bridge', hide=True,
+                       modes=[typ.KeyMode.command, typ.KeyMode.prompt])
+    def rl_unix_word_rubout(self):
+        """Remove chars from the cursor to the beginning of the word.
+
+        This acts like readline's unix-word-rubout. Whitespace is used as a
+        word delimiter.
+        """
+        self._rubout([' '])
+
+    @cmdutils.register(instance='readline-bridge', hide=True,
+                       modes=[typ.KeyMode.command, typ.KeyMode.prompt])
+    def rl_unix_filename_rubout(self):
+        """Remove chars from the cursor to the previous path separator.
+
+        This acts like readline's unix-filename-rubout.
+        """
+        self._rubout([' ', '/'])
+
+    @cmdutils.register(instance='readline-bridge', hide=True,
+                       modes=[typ.KeyMode.command, typ.KeyMode.prompt])
+    def rl_backward_kill_word(self):
+        """Remove chars from the cursor to the beginning of the word.
+
+        This acts like readline's backward-kill-word. Any non-alphanumeric
+        character is considered a word delimiter.
+        """
+        widget = self._widget()
+        if widget is None:
+            return
+        widget.cursorWordBackward(True)
+        self._deleted[widget] = widget.selectedText()
+        widget.del_()
+
     @cmdutils.register(instance='readline-bridge', hide=True,
                        modes=[typ.KeyMode.command, typ.KeyMode.prompt])
     def rl_kill_word(self):
