@@ -115,13 +115,16 @@ def message_error(text):
 
 
 @cmdutils.register(hide=True)
-def message_info(text):
+@cmdutils.argument('count', count=True)
+def message_info(text, count=1):
     """Show an info message in the statusbar.
 
     Args:
         text: The text to show.
+        count: How many times to show the message
     """
-    message.info(text)
+    for _ in range(count):
+        message.info(text)
 
 
 @cmdutils.register(hide=True)
