@@ -22,6 +22,8 @@
 import os
 import os.path
 import traceback
+import mimetypes
+import html
 
 import jinja2
 import jinja2.exceptions
@@ -30,6 +32,24 @@ from qutebrowser.utils import utils, urlutils, log
 
 from PyQt5.QtCore import QUrl
 
+html_fallback = """
+<!DOCTYPE html>
+<html>
+  <head>
+    <meta charset="utf-8">
+    <title>Error while loading template</title>
+  </head>
+  <body>
+    <p><span style="font-size:120%;color:red">
+    The %FILE% template could not be found!<br>
+    Please check your qutebrowser installation
+      </span><br>
+      %ERROR%
+    </p>
+  </body>
+</html>
+"""
+
 
 class Loader(jinja2.BaseLoader):
 
@@ -46,8 +66,11 @@ class Loader(jinja2.BaseLoader):
         path = os.path.join(self._subdir, template)
         try:
             source = utils.read_file(path)
-        except OSError:
-            raise jinja2.TemplateNotFound(template)
+        except OSError as e:
+            source = html_fallback.replace("%ERROR%", html.escape(str(e)))
+            source = source.replace("%FILE%", html.escape(template))
+            log.misc.exception("The {} template could not be loaded from {}"
+                               .format(template, path))
         # Currently we don't implement auto-reloading, so we always return True
         # for up-to-date.
         return source, path, lambda: True
@@ -74,6 +97,15 @@ def resource_url(path):
     return QUrl.fromLocalFile(image).toString(QUrl.FullyEncoded)
 
 
+def data_url(path):
+    """Get a data: url for the broken qutebrowser logo."""
+    data = utils.read_file(path, binary=True)
+    filename = utils.resource_filename(path)
+    mimetype = mimetypes.guess_type(filename)
+    assert mimetype is not None, path
+    return urlutils.data_url(mimetype[0], data).toString()
+
+
 def render(template, **kwargs):
     """Render the given template and pass the given arguments to it."""
     try:
@@ -89,3 +121,4 @@ def render(template, **kwargs):
 _env = jinja2.Environment(loader=Loader('html'), autoescape=_guess_autoescape)
 _env.globals['resource_url'] = resource_url
 _env.globals['file_url'] = urlutils.file_url
+_env.globals['data_url'] = data_url
