@@ -34,7 +34,7 @@ import operator
 import contextlib
 
 from PyQt5.QtCore import (qVersion, QEventLoop, QDataStream, QByteArray,
-                          QIODevice, QSaveFile)
+                          QIODevice, QSaveFile, QT_VERSION_STR)
 from PyQt5.QtWidgets import QApplication
 
 from qutebrowser.utils import log
@@ -80,15 +80,22 @@ class QtOSError(OSError):
             self.qt_errno = None
 
 
-def version_check(version, op=operator.ge):
+def version_check(version, op=operator.ge, strict=False):
     """Check if the Qt runtime version is the version supplied or newer.
 
     Args:
         version: The version to check against.
         op: The operator to use for the check.
+        strict: If given, also check the compiled Qt version.
     """
-    return op(pkg_resources.parse_version(qVersion()),
-              pkg_resources.parse_version(version))
+    if strict:
+        assert op in [operator.ge, operator.lt], op
+    parsed = pkg_resources.parse_version(version)
+    result = op(pkg_resources.parse_version(qVersion()), parsed)
+    if ((strict and op == operator.ge and result) or
+            (strict and op == operator.lt and not result)):
+        result = op(pkg_resources.parse_version(QT_VERSION_STR), parsed)
+    return result
 
 
 def is_qtwebkit_ng(version):
@@ -141,11 +148,11 @@ def get_args(namespace):
     argv = [sys.argv[0]]
 
     if namespace.qt_flag is not None:
-        argv += ['-' + flag[0] for flag in namespace.qt_flag]
+        argv += ['--' + flag[0] for flag in namespace.qt_flag]
 
     if namespace.qt_arg is not None:
         for name, value in namespace.qt_arg:
-            argv += ['-' + name, value]
+            argv += ['--' + name, value]
 
     return argv
 
